AppLocalizations class

Constructors

AppLocalizations(Locale locale)

Properties

hashCode int
The hash code for this object.
no setterinherited
locale Locale
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getString(String key) String
获取字符串信息
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

assets String
路径
getter/setter pair
package String?
getter/setter pair
supportedLocales List<Locale>
i18n 库支持的语言 扩展位置,写在 main 函数中 runApp 之前
getter/setter pair

Static Methods

of(BuildContext context) AppLocalizations?

Constants

TAG → const String